import { expect, tap } from '@pushrocks/tapbundle';
import * as smartnpm from '../ts/index';
import { NpmRegistry } from '../ts/index';

let npmRegistry: smartnpm.NpmRegistry;
let verdaccioRegistry: smartnpm.NpmRegistry;
let testPackage: smartnpm.NpmPackage;

// lets test things with the standard npm registry
tap.test('should create valid instances', async () => {
  npmRegistry = new smartnpm.NpmRegistry();
  expect(npmRegistry).to.be.instanceof(smartnpm.NpmRegistry);

  testPackage = new smartnpm.NpmPackage(npmRegistry);
  expect(testPackage).to.be.instanceof(smartnpm.NpmPackage);
});

tap.test('should produce a valid search string and this return npmts', async () => {
  const packages = await npmRegistry.searchOnNpm({
    name: '@pushrocks/smartupdate',
  });
  expect(packages[0].name).to.equal('@pushrocks/smartupdate');
});

// lets test things with the verdaccio registry
tap.test('should create a verdaccio registry', async () => {
  verdaccioRegistry = new NpmRegistry({
    npmRegistryUrl: 'https://verdaccio.lossless.one',
  });
  expect(verdaccioRegistry).to.be.instanceOf(smartnpm.NpmRegistry);
});

tap.test('should get package from verdaccio', async () => {
  const npmPackage = await verdaccioRegistry.getPackageInfo('@pushrocks/smartupdate');
  console.log(npmPackage);
  expect(npmPackage.license).to.equal('MIT');
});

tap.test('should get a specific file from a package', async () => {
  const bundleFile = await verdaccioRegistry.getFileFromPackage(
    '@pushrocks/websetup',
    'ts/index.ts'
  );
  console.log(bundleFile.contentBuffer.toString());
});

tap.start();

const hi = {
  _id: '@pushrocks/smartversion',
  _rev: '2-93b6e6391f7209fcbd1db76c92164777',
  name: '@pushrocks/smartversion',
  'dist-tags': { latest: '2.0.4' },
  versions: {
    '2.0.0': {
      name: '@pushrocks/smartversion',
      version: '2.0.0',
      private: false,
      description: 'handle semver with easy',
      main: 'dist/index.js',
      typings: 'dist/index.d.ts',
      author: { name: 'Lossless GmbH' },
      license: 'MIT',
      scripts: { test: '(tstest test/)', build: '(tsbuild)' },
      devDependencies: {
        '@gitzone/tsbuild': '^2.0.22',
        '@gitzone/tsrun': '^1.1.12',
        '@gitzone/tstest': '^1.0.15',
        '@pushrocks/tapbundle': '^3.0.5',
        '@types/node': '^10.9.4',
      },
      dependencies: { '@types/semver': '^5.5.0', semver: '^5.5.1' },
      gitHead: 'df6b1a9730551884aa4c4fae5577b2b11058f508',
      _id: '@pushrocks/smartversion@2.0.0',
      _npmVersion: '6.2.0',
      _nodeVersion: '10.9.0',
      _npmUser: { name: 'lossless', email: 'npm@lossless.com' },
      dist: {
        integrity:
          'sha512-+loQHivWzEO39X/PEzi+UOptDveez0n8Eu/bDIht55wkjhav33HkNjab8MeK/g76gOia3ZHoPyqLTvD4yvXDiA==',
        shasum: 'd663a39d77950de1a743adb0c2eb00e325d230df',
        tarball: 'https://registry.npmjs.org/@pushrocks/smartversion/-/smartversion-2.0.0.tgz',
        fileCount: 12,
        unpackedSize: 12011,
        'npm-signature':
          '-----BEGIN PGP SIGNATURE-----\r\nVersion: OpenPGP.js v3.0.4\r\nComment: https://openpgpjs.org\r\n\r\nwsFcBAEBCAAQBQJbi7zUCRA9TVsSAnZWagAAigcP/0gRmizQkzjE9Gw8gCeK\n56m41mJQmtl6tRvYVyVGuqfiCaiLvB/B0fkKt2r/MNsJVjC372ayWKya4nev\nTOLSg+g4e9gnkyn8i1OFVE5kr8C4MvLc6P771v2UDXJF5c3pYq6i5fSyGz/s\ngpOuy/KxyVo5wH16yasGWDq9Gl58yp+7vZKR6cc+7Rlq0UhyezhDBRBiKkB0\nk6Y/4J4KWK7CmO+3Y/QUPGBxGmoUHNSiS5cz8vWbycRP7pT11asksgxNPGdv\nyeW/VNVLZkemwrXhSuYKM0DK6aZpjJxk3A8OAyDuHGfZDzAmyaRsfUL84Mgl\nlN1S92CCfuAOyA1os8rsrJU133TV8zVTck3IdmO4AqJ8aB3WNkmNYE5IHxWf\nnmhUUo1Rv/M5fJniTHOBGaeOahFqEp+8URNW1zylC3NoFwiUon1lvnMp1Dd1\nczGPWvQ12ZAeMOR/qpO4RRzTdD45iuvvj2NRhZZN1pthnhUi8XpgMIDuCODT\n2Srew7JBkdfX3F1q/LGgk9e+RYCWTlLPgmzOBUH39ljpfa70liAH5sU+yyfk\nFLfVQlLwWAEwRnkm4j/l/xBWJcwqVG2nDOOzScfYVG3BXSBHo4PfywhFdbnc\nQ3MMrJsrJPhppfMJEEQWlQSkNSCCEV7DDPeH4oK9tKRUdmDaKJpnb6tVZqzM\nBWac\r\n=0NZU\r\n-----END PGP SIGNATURE-----\r\n',
      },
      maintainers: [{ name: 'lossless', email: 'npm@lossless.com' }],
      directories: {},
      _npmOperationalInternal: {
        host: 's3://npm-registry-packages',
        tmp: 'tmp/smartversion_2.0.0_1535884499821_0.9273118882229912',
      },
      _hasShrinkwrap: false,
    },
    '2.0.3': {
      name: '@pushrocks/smartversion',
      version: '2.0.3',
      private: false,
      description: 'handle semver with easy',
      main: 'dist/index.js',
      typings: 'dist/index.d.ts',
      author: { name: 'Lossless GmbH' },
      license: 'MIT',
      scripts: { test: '(tstest test/)', build: '(tsbuild)' },
      devDependencies: {
        '@gitzone/tsbuild': '^2.1.17',
        '@gitzone/tsrun': '^1.2.8',
        '@gitzone/tstest': '^1.0.24',
        '@pushrocks/tapbundle': '^3.0.13',
        '@types/node': '^12.7.5',
      },
      dependencies: { '@types/semver': '^6.0.2', semver: '^6.3.0' },
      gitHead: 'e364545d0ef6ef7fa1b8467fb48d2b67f09f2d07',
      _id: '@pushrocks/smartversion@2.0.3',
      _nodeVersion: '12.10.0',
      _npmVersion: '6.11.3',
      dist: {
        integrity:
          'sha512-nhauxBGMxjJtXj+k1Z7H2yB184ZhWhU0NKN5ATwlgfEM4zbbZNjCFRLVg/7sOXvbS2b0QU1aStRQ+6QGC2hW4A==',
        shasum: '9272da89412556946c5a3d5ba3b6a253154de6ae',
        tarball: 'https://registry.npmjs.org/@pushrocks/smartversion/-/smartversion-2.0.3.tgz',
        fileCount: 9,
        unpackedSize: 9127,
        'npm-signature':
          '-----BEGIN PGP SIGNATURE-----\r\nVersion: OpenPGP.js v3.0.4\r\nComment: https://openpgpjs.org\r\n\r\nwsFcBAEBCAAQBQJdeRYfCRA9TVsSAnZWagAApCkP/RrWk6+hxpoTpflJ65x/\nm05egDhfyTs2BZKArkSnvtc+q6Fo3iDlumqiv3HRyHwDBFLgK5gAOgU0jyqW\nmhwumGMfKT4bzG65iU2z6FgS+RhEh3JaKzjgPohr1oEaLOaaKL0S9+Ybxt6u\nkwv4CgnmzQ/6zVZYJ+qFbV0v+n6iiuIbOTS8j7+X0nA/DkvvZ1Nwhng++vH8\nLm8lT78F/vcxHkSf2RfC6kabhVF+vVRBazq/cI4OQ+xjBQC2y+6YxEq/4Hsz\nKZBF9u2ZcyeI7NEuo1FaojvqvLX3lPxi9Xfw2PSO2iri+DS8KIOVgzwJ+9ih\nb1h/vpoFv8dbhZzkqSs/4rab3rvQYqy7AgvslI8mEeOQk/BhrjxQIvG0re3H\nzc0iWlNp6W3Lsf3/gmKGZbhl39ZgQxInfWLNW60ghqzUq85gyAwPDRb2yxez\nP7bMT0qb/bQSmAa63/q3qE+JAjZFQFDB6Pj6sO1p3csv0T+7mRj9T/4pSc8B\nv5rD9t0mVlAZXwmz3zDhpomct3bhUlAidw7tcax8sr9SowA2hqY3TB1uJ52y\nKPDVMQZ4Voi7kft+icYoVm1XkQMwmmedAoTbS49s52wW6dm4CWmnlBOZzzqN\neT4Q1INrTUXaMxRv/zxguk7TV8xi6gRf+EBDtnEKukITWTvvPsGq4SS9toRa\n9L6F\r\n=yVBx\r\n-----END PGP SIGNATURE-----\r\n',
      },
      maintainers: [{ name: 'lossless', email: 'npm@lossless.com' }],
      _npmUser: { name: 'lossless', email: 'npm@lossless.com' },
      directories: {},
      _npmOperationalInternal: {
        host: 's3://npm-registry-packages',
        tmp: 'tmp/smartversion_2.0.3_1568216607132_0.9216415895294796',
      },
      _hasShrinkwrap: false,
    },
    '2.0.4': {
      name: '@pushrocks/smartversion',
      version: '2.0.4',
      private: false,
      description: 'handle semver with easy',
      main: 'dist/index.js',
      typings: 'dist/index.d.ts',
      author: { name: 'Lossless GmbH' },
      license: 'MIT',
      scripts: { test: '(tstest test/)', build: '(tsbuild)' },
      devDependencies: {
        '@gitzone/tsbuild': '^2.1.17',
        '@gitzone/tsrun': '^1.2.8',
        '@gitzone/tstest': '^1.0.24',
        '@pushrocks/tapbundle': '^3.0.13',
        '@types/node': '^12.7.5',
        tslint: '^5.20.0',
        'tslint-config-prettier': '^1.18.0',
      },
      dependencies: { '@types/semver': '^6.0.2', semver: '^6.3.0' },
      gitHead: 'bb8e7cb608f3a116e7bfb0b52dd5ce9a7c4eaec1',
      _id: '@pushrocks/smartversion@2.0.4',
      _nodeVersion: '12.10.0',
      _npmVersion: '6.11.3',
      dist: {
        integrity:
          'sha512-LrtaWRn1DD2zIUr8nVAsKwZ+Y55TFIVZ0z3xjwAQ46SoiTrFWooeQ2Xw18DqsEo1cEqMZyGAskaJkOaRkXHtUA==',
        shasum: '7c6297f9c596e729001c2b6e2a8fa72c40ed42a9',
        tarball: 'https://registry.npmjs.org/@pushrocks/smartversion/-/smartversion-2.0.4.tgz',
        fileCount: 9,
        unpackedSize: 9263,
        'npm-signature':
          '-----BEGIN PGP SIGNATURE-----\r\nVersion: OpenPGP.js v3.0.4\r\nComment: https://openpgpjs.org\r\n\r\nwsFcBAEBCAAQBQJdeRazCRA9TVsSAnZWagAAxX0P/j12DYB5zjZQh3/IpY1t\n+vzvLmTgn2b0lhheLxUX9EYMW+cethYbd8Q8p/SOsytfB2IHCKBdkpE5ZAIK\nsv7d/myZaihZ9RHCd/UQOj99b/KfdbN/7ndtEL7V4hmcNyWUmebeRsxMhxZ5\nLRvWMZiNsgdXbKxs6JpId3iuSFuTxRgL41smiklcW0nGRp9uMieN8TC3xmOW\nsia6JcvGNQT1/LD9XN6l9U/ZWfzOMaEtjv4Hd9XzOVv0SMYT5Nyv3JQV2Jd5\nc5G5aGZe0QXSB9LwnNUcXC3mrZ9+SvmqpECcV2BTJ+JJlzp4Pny51r2nPyC6\nypdsfTfDzAL6BIq433OScEyjRMcufLC+caGXPCjUhtPW6wlf9kTFiRd2L3uk\nWhg2LmFhL4bHz67ty2wAy8XlLYOS/QFOZLEZr7bZDhINkkqR5RQd5RfkMJ6Q\n0skcsspq69tWKrgY3Uh6aK30Z+g7C4V/KGfquz6EsET9xP+7MRTVcd+FLfC1\ndfCcfe3/l49oXbCPwApH9X8ETc3HDJuSRdfVV7PVsEzbOwN4sqTIS9vAHXDN\ncjAmrhbZkhA7VD4PNjhEov1veo/UOoNB7xlN4JLuRZ40SqCSr4akVnNImUDc\nCg+b16mZhlVpLNgjVjG9rgDD7zCn+zn9EZTsq3/qL4jEcf4JY+T2YKmf7AMb\nhmej\r\n=eqby\r\n-----END PGP SIGNATURE-----\r\n',
      },
      maintainers: [{ name: 'lossless', email: 'npm@lossless.com' }],
      _npmUser: { name: 'lossless', email: 'npm@lossless.com' },
      directories: {},
      _npmOperationalInternal: {
        host: 's3://npm-registry-packages',
        tmp: 'tmp/smartversion_2.0.4_1568216754658_0.06886864906713819',
      },
      _hasShrinkwrap: false,
    },
  },
  time: {
    created: '2018-09-02T10:34:59.735Z',
    '2.0.0': '2018-09-02T10:34:59.913Z',
    modified: '2019-09-11T15:45:58.404Z',
    '2.0.3': '2019-09-11T15:43:27.294Z',
    '2.0.4': '2019-09-11T15:45:54.786Z',
  },
  maintainers: [{ name: 'lossless', email: 'npm@lossless.com' }],
  description: 'handle semver with easy',
  author: { name: 'Lossless GmbH' },
  license: 'MIT',
  readme:
    '# @pushrocks/smartversion\nhandle semver with easy\n\n## Availabililty and Links\n* [npmjs.org (npm package)](https://www.npmjs.com/package/@pushrocks/smartversion)\n* [gitlab.com (source)](https://gitlab.com/pushrocks/smartversion)\n* [github.com (source mirror)](https://github.com/pushrocks/smartversion)\n* [docs (typedoc)](https://pushrocks.gitlab.io/smartversion/)\n\n## Status for master\n[![build status](https://gitlab.com/pushrocks/smartversion/badges/master/build.svg)](https://gitlab.com/pushrocks/smartversion/commits/master)\n[![coverage report](https://gitlab.com/pushrocks/smartversion/badges/master/coverage.svg)](https://gitlab.com/pushrocks/smartversion/commits/master)\n[![npm downloads per month](https://img.shields.io/npm/dm/@pushrocks/smartversion.svg)](https://www.npmjs.com/package/@pushrocks/smartversion)\n[![Known Vulnerabilities](https://snyk.io/test/npm/@pushrocks/smartversion/badge.svg)](https://snyk.io/test/npm/@pushrocks/smartversion)\n[![TypeScript](https://img.shields.io/badge/TypeScript->=%203.x-blue.svg)](https://nodejs.org/dist/latest-v10.x/docs/api/)\n[![node](https://img.shields.io/badge/node->=%2010.x.x-blue.svg)](https://nodejs.org/dist/latest-v10.x/docs/api/)\n[![JavaScript Style Guide](https://img.shields.io/badge/code%20style-prettier-ff69b4.svg)](https://prettier.io/)\n\n## Usage\n\nUse TypeScript for best in class instellisense.\n\nFor further information read the linked docs at the top of this readme.\n\n> MIT licensed | **&copy;** [Lossless GmbH](https://lossless.gmbh)\n| By using this npm module you agree to our [privacy policy](https://lossless.gmbH/privacy)\n\n[![repo-footer](https://lossless.gitlab.io/publicrelations/repofooter.svg)](https://maintainedby.lossless.com)\n',
  readmeFilename: 'readme.md',
};
